import { Component, AfterViewInit, OnDestroy } from '@angular/core';
import * as echarts from 'echarts';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';


@Component({
  selector: 'app-page-vibration-analysis',
  standalone: true,
  imports: [CommonModule, RouterModule],
  templateUrl: './page-vibration-analysis.html',
  styleUrls: ['./page-vibration-analysis.scss']
})
export class PageVibrationAnalysis implements AfterViewInit, OnDestroy {
  private fftChart!: echarts.ECharts;
  private featureChart!: echarts.ECharts;

  ngAfterViewInit() {
    this.initCharts();
    window.addEventListener('resize', this.onWindowResize);
  }

  ngOnDestroy() {
    window.removeEventListener('resize', this.onWindowResize);
    this.fftChart?.dispose();
    this.featureChart?.dispose();
  }

  private onWindowResize = () => {
    this.fftChart?.resize();
    this.featureChart?.resize();
  };

  private initCharts() {
    this.fftChart = echarts.init(document.getElementById('fft-chart') as HTMLElement);
    this.fftChart.setOption(this.getFFTChartOption());

    this.featureChart = echarts.init(document.getElementById('feature-chart') as HTMLElement);
    this.featureChart.setOption(this.getFeatureChartOption());
  }

  private getFFTChartOption(): echarts.EChartsOption {
    return {
      backgroundColor: 'transparent',
      grid: {
        top: 30,
        right: 30,
        bottom: 40,
        left: 50
      },
      tooltip: {
        trigger: 'axis'
      },
      xAxis: {
        type: 'category',
        name: '频率 (Hz)',
        nameLocation: 'middle',
        nameGap: 30,
        data: Array.from({length: 100}, (_, i) => i * 0.5),
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999'
        }
      },
      yAxis: {
        type: 'value',
        name: '幅值 (g)',
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999'
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(255, 255, 255, 0.05)'
          }
        }
      },
      series: [
        {
          name: '频谱',
          type: 'line',
          smooth: true,
          data: this.generateFFTData(),
          lineStyle: {
            width: 2,
            color: '#00b6c1'
          },
          itemStyle: {
            color: '#00b6c1'
          },
          areaStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0, color: 'rgba(0, 182, 193, 0.7)' },
              { offset: 1, color: 'rgba(0, 182, 193, 0.1)' }
            ])
          },
          symbol: 'none'
        }
      ]
    };
  }

private getFeatureChartOption(): echarts.EChartsOption {
  return {
    backgroundColor: 'transparent',
    grid: {
      top: 30,
      right: 30,
      bottom: 40,
      left: 50
    },
    tooltip: {
      trigger: 'axis'
    },
    radar: {
      indicator: [
        { name: 'RMS', max: 2 },
        { name: '峰值', max: 5 },
        { name: '峭度', max: 5 },
        { name: '峰值因子', max: 10 },
        { name: '脉冲指标', max: 10 }
      ],
      radius: '65%',
      axisLine: {
        lineStyle: {
          color: 'rgba(255, 255, 255, 0.2)'
        }
      },
      splitLine: {
        lineStyle: {
          color: 'rgba(255, 255, 255, 0.1)'
        }
      },
      splitArea: {
        show: false
      },
      axisName: {  // 修改这里，从 name 改为 axisName
        color: '#ccc',
        fontSize: 12
      }
    },
    series: [
      {
        name: '特征值',
        type: 'radar',
        data: [
          {
            value: [1.24, 3.56, 3.78, 4.56, 5.23],
            name: '当前状态',
            areaStyle: {
              color: 'rgba(0, 182, 193, 0.4)'
            },
            lineStyle: {
              width: 2,
              color: '#00b6c1'
            },
            itemStyle: {
              color: '#00b6c1'
            }
          }
        ]
      }
    ]
  };
}

  private generateFFTData(): number[] {
    const data = [];
    for (let i = 0; i < 100; i++) {
      const x = i * 0.5;
      let y = Math.exp(-x / 10) * (2 + Math.sin(x * 2) + Math.random() * 0.1)
      
      // 添加特征频率峰值
      if (Math.abs(x - 12.5) < 0.3) y += 0.8;
      if (Math.abs(x - 25) < 0.3) y += 0.6;
      if (Math.abs(x - 37.5) < 0.3) y += 0.4;
      
      data.push(y);
    }
    return data;
  }
}