import { Component, AfterViewInit, OnDestroy } from '@angular/core';
import * as echarts from 'echarts';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';

@Component({
  selector: 'app-page-vibration-history',
  standalone: true,
  imports: [CommonModule, RouterModule],
  templateUrl: './page-vibration-history.html',
  styleUrls: ['./page-vibration-history.scss']
})
export class PageVibrationHistory implements AfterViewInit, OnDestroy {
  showCustomRange = false;
  currentPage = 1;
  totalPages = 5;
  
  events = [
    {
      time: '2025-06-15 14:23:45',
      type: '振动超标',
      device: 'CNC-01',
      value: 2.8,
      duration: '12秒'
    },
    {
      time: '2025-06-15 10:12:33',
      type: '刀具磨损',
      device: 'CNC-02',
      value: 1.2,
      duration: '持续'
    },
    {
      time: '2025-06-14 18:45:21',
      type: '正常停机',
      device: 'CNC-01',
      value: 0.5,
      duration: '3分12秒'
    },
    {
      time: '2025-06-14 09:30:15',
      type: '严重故障',
      device: 'CNC-03',
      value: 4.2,
      duration: '2分45秒'
    },
    {
      time: '2025-06-13 16:20:08',
      type: '振动超标',
      device: 'CNC-02',
      value: 2.1,
      duration: '8秒'
    }
  ];

  private trendChart!: echarts.ECharts;
  private eventChart!: echarts.ECharts;

  ngAfterViewInit() {
    this.initCharts();
    window.addEventListener('resize', this.onWindowResize);
  }

  ngOnDestroy() {
    window.removeEventListener('resize', this.onWindowResize);
    this.trendChart?.dispose();
    this.eventChart?.dispose();
  }

  private onWindowResize = () => {
    this.trendChart?.resize();
    this.eventChart?.resize();
  };

  private initCharts() {
    this.trendChart = echarts.init(document.getElementById('trend-chart') as HTMLElement);
    this.trendChart.setOption(this.getTrendChartOption());

    this.eventChart = echarts.init(document.getElementById('event-chart') as HTMLElement);
    this.eventChart.setOption(this.getEventChartOption());
  }

  private getTrendChartOption(): echarts.EChartsOption {
    const hours = Array.from({length: 24}, (_, i) => `${i}:00`);
    const data = hours.map((_, i) => {
      return 0.5 + Math.sin(i / 3) * 0.8 + Math.random() * 0.3;
    });

    return {
      backgroundColor: 'transparent',
      grid: {
        top: 30,
        right: 30,
        bottom: 40,
        left: 50
      },
      tooltip: {
        trigger: 'axis'
      },
      xAxis: {
        type: 'category',
        data: hours,
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999',
          rotate: 45
        }
      },
      yAxis: {
        type: 'value',
        name: '振动值 (g)',
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999'
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(255, 255, 255, 0.05)'
          }
        }
      },
      series: [
        {
          name: '振动值',
          type: 'line',
          smooth: true,
          data: data,
          lineStyle: {
            width: 2,
            color: '#00b6c1'
          },
          itemStyle: {
            color: '#00b6c1'
          },
          areaStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0, color: 'rgba(0, 182, 193, 0.7)' },
              { offset: 1, color: 'rgba(0, 182, 193, 0.1)' }
            ])
          },
          markLine: {
            silent: true,
            lineStyle: {
              color: '#ff9800',
              width: 1,
              type: 'dashed'
            },
            data: [
              {
                yAxis: 1.5,
                label: {
                  formatter: '警告阈值',
                  position: 'start'
                }
              },
              {
                yAxis: 2.0,
                label: {
                  formatter: '危险阈值',
                  position: 'start'
                },
                lineStyle: {
                  color: '#f44336'
                }
              }
            ]
          }
        }
      ]
    };
  }

  private getEventChartOption(): echarts.EChartsOption {
    return {
      backgroundColor: 'transparent',
      grid: {
        top: 30,
        right: 30,
        bottom: 40,
        left: 50
      },
      tooltip: {
        trigger: 'axis'
      },
      xAxis: {
        type: 'category',
        data: ['周一', '周二', '周三', '周四', '周五', '周六', '周日'],
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999'
        }
      },
      yAxis: {
        type: 'value',
        name: '事件次数',
        axisLine: {
          lineStyle: {
            color: '#666'
          }
        },
        axisLabel: {
          color: '#999'
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(255, 255, 255, 0.05)'
          }
        }
      },
      series: [
        {
          name: '警告事件',
          type: 'bar',
          barGap: 0,
          barWidth: 15,
          data: [2, 1, 3, 2, 1, 0, 1],
          itemStyle: {
            color: '#ff9800'
          }
        },
        {
          name: '严重事件',
          type: 'bar',
          barWidth: 15,
          data: [0, 1, 0, 1, 0, 0, 0],
          itemStyle: {
            color: '#f44336'
          }
        }
      ],
      legend: {
        data: ['警告事件', '严重事件'],
        textStyle: {
          color: '#ccc'
        },
        top: 0
      }
    };
  }

  toggleCustomRange(show: boolean) {
    this.showCustomRange = show;
  }

  prevPage() {
    if (this.currentPage > 1) {
      this.currentPage--;
    }
  }

  nextPage() {
    if (this.currentPage < this.totalPages) {
      this.currentPage++;
    }
  }
}